@@ -12,8 +12,8 @@
 
 // CUDA settings
 #define MAGMA_HAVE_CUDA
-#define MAGMA_CUDA_ARCH "50;60;70;80;90;100;120"
-#define MAGMA_CUDA_ARCH_MIN 500
+#define MAGMA_CUDA_ARCH "75;80;86;87;88;89;90;100;103;110;120;121"
+#define MAGMA_CUDA_ARCH_MIN 750
 
 // HIP settings
 /* #undef MAGMA_HAVE_HIP */
